#' Spell check search term for occurrence searches
#'
#' @export
#' @rdname occ_spellcheck-defunct
#' @keywords internal
#' @param ... ignored
occ_spellcheck <- function(...) { # nocov start
  .Defunct(msg="the spellCheck parameter has been removed")
} # nocov end
